@@ -10,7 +10,7 @@ decorator.
 __author__ = "Jakob Simon-Gaarde"
 
 from ladon.ladonizer.collection import global_service_collection
-from ladon.types import validate_type,result_to_dict
+from ladon.types import validate_type,expand_value,result_to_dict
 from ladon.exceptions.ladonizer import *
 import ladon.tools.log as log
 import time
@@ -81,7 +81,7 @@ def ladonize(*def_args,**def_kw):
 				# Build a request_dict for debugging
 				req_dict = {}
 				for argidx in range(len(callargs)):
-					req_dict[lmi._arg_names[argidx]] = callargs[argidx]
+					req_dict[lmi._arg_names[argidx]] = expand_value(callargs[argidx],lmi._arg_types[argidx],service_name=lmi.sinfo.servicename,method_name=lmi._func_name)
 				log_line = [
 					'Method:%s.%s' % (lmi.sinfo.servicename,lmi._func_name),
 					'RequestArgs:%s' % str(req_dict),
